﻿using Hotline.Application.Snapshot;
using Hotline.Share.Dtos;
using Hotline.Share.Dtos.Snapshot;
using Microsoft.AspNetCore.Mvc;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Tools;
using Hotline.Snapshot.Interfaces;
using Hotline.Settings.Hotspots;
using Hotline.Share.Requests;
using SqlSugar;
using XF.Domain.Authentications;
using Hotline.Settings;
using Hotline.Caching.Interfaces;
using Hotline.Share.Enums.Order;
using Hotline.Share.Enums.Snapshot;
using XF.Utility.EnumExtensions;
using Amazon.Runtime.Internal.Util;

namespace Hotline.Api.Controllers.Snapshot;

/// <summary>
/// 随手拍统计
/// </summary>
public class BiSnapshotController : BaseController
{
    private readonly IBiSnapshotApplication _biSnapshotApplication;
    private readonly IIndustryRepository _industryRepository;

    public BiSnapshotController(IBiSnapshotApplication biSnapshotApplication, IIndustryRepository industryRepository)
    {
        _biSnapshotApplication = biSnapshotApplication;
        _industryRepository = industryRepository;
    }

    /// <summary>
    /// 随手拍统计基础数据
    /// </summary>
    /// <returns></returns>
    [HttpGet("statistics/basedata")]
    public async Task<Dictionary<string, object>> GetSnapshotStatisticsBaseDataAsync()
    {
        return new Dictionary<string, object>()
        {
            { "industry", await _industryRepository.GetDataBaseAsync() }
        };
    }

    /// <summary>
    /// 随手拍统计
    /// </summary>
    /// <returns></returns>
    [HttpGet("statistics")]
    public async Task<SnapshotStatisticsOutDto> GetSnapshotStatisticsAsync([FromQuery] SnapshotStatisticsInDto dto)
        => await _biSnapshotApplication.GetSnapshotStatisticsAsync(dto, HttpContext.RequestAborted);

    /// <summary>
    /// 随手拍统计详情集合
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("statistics/details")]
    public async Task<PagedDto<SnapshotStatisticsDetailOutDto>> GetSnapshotStatisticsDetailAsync([FromQuery] SnapshotStatisticsDetailInDto dto)
        => (await _biSnapshotApplication.GetSnapshotStatisticsDetail(dto).ToPagedListAsync(dto)).ToPaged();


    /// <summary>
    /// 市民红包审核统计
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("redpack/audit")]
    public IList<RedPackStatisticsOutDto> GetRedPackAuditStatisticsAsync([FromQuery] RedPackStatisticsInDto dto)
        => _biSnapshotApplication.GetRedPackAuditStatistics(dto);

    /// <summary>
    /// 市民红包审核统计详情
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("redpack/audit/details")]
    public async Task<PagedDto<RedPackStatisticsDetailsOutDto>> GetRedPackAuditStatisticsDetailsAsync([FromQuery] RedPackStatisticsDetailsInDto dto)
        => (await _biSnapshotApplication.GetRedPackAuditStatisticsDetails(dto).ToPagedListAsync(dto)).ToPaged();

    /// <summary>
    /// 热点类型小类统计
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("hotspot-statistics")]
    public async Task<IList<HotspotStatisticsOutDto>> GetHotspotStatisticsAsync([FromQuery] HotspotStatisticsInDto dto)
        => await _biSnapshotApplication.GetHotspotStatistics(dto).ToListAsync();

    /// <summary>
    /// 热点类型小类统计明细
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("hotspot-statistics-detail")]
    public async Task<PagedDto<HotspotStatisticsDetailsOutDto>> GetHotspotStatisticsDetailAsync([FromQuery] HotspotStatisticsDetailsInDto dto)
        => (await _biSnapshotApplication.HotspotStatisticsDetail(dto).ToPagedListAsync(dto)).ToPaged();

    /// <summary>
    /// 热点类型-随手拍
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("hotspot-data-statistics")]
    public async Task<IList<HotspotDataStatisticsOutDto>> GetHotspotDataStatisticsAsync([FromQuery] HotspotDataStatisticsInDto dto)
    {
        var items = await _biSnapshotApplication.GetHotspotDataStatisticsAsync(dto).ToListAsync();
        items.Add(new HotspotDataStatisticsOutDto
        {
            Name = "合计",
            OrderCount = items.Sum(x => x.OrderCount),
        });
        return items;
    }

    /// <summary>
    /// 办件统计-随手拍
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("processing-statistics")]
    public async Task<IList<SnapshotProcessingStatisticsOutDto>> GetSnapshotProcessingStatistics([FromQuery] SnapshotProcessingStatisticsInDto dto)
        => await _biSnapshotApplication.GetSnapshotProcessingStatistics(dto).ToListAsync();

    /// <summary>
    /// 办件统计明细-随手拍
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("processing-statistics-detail")]
    public async Task<PagedDto<SnapshotProcessingStatisticsDetailsOutDto>> GetSnapshotProcessingStatisticsDetails([FromQuery]SnapshotProcessingStatisticsDetailsInDto dto)
        => (await _biSnapshotApplication.GetSnapshotProcessingStatisticsDetails(dto).ToPagedListAsync(dto)).ToPaged();

    /// <summary>
    /// 网格员办理情况统计
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("guider-work-statistics")]
    public async Task<IList<GuiderWorkStatisticsOutDto>> GetGuiderWorkStatisticsAsync([FromQuery] GuiderWorkStatisticsInDto dto)
        => await _biSnapshotApplication.GetGuiderWorkStatisticsAsync(dto).ToListAsync();

    /// <summary>
    /// 网格员办理情况统计详情
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("guider-work-statistics-detail")]
    public async Task<PagedDto<GuiderWorkStatisticsDetailsOutDto>> GetGuiderWorkStatisticsDetailsAsync([FromQuery] GuiderWorkStatisticsDetailsInDto dto)
        => (await _biSnapshotApplication.GetGuiderWorkStatisticsDetails(dto).ToPagedListAsync(dto)).ToPaged();

    /// <summary>
    /// 网格员系统工单状态日志基础数据
    /// </summary>
    /// <returns></returns>
    [HttpGet("guider-work-log/basedata")]
    public async Task<Dictionary<string, object>> GetGuiderWorkLogsAsyncBasedataAsync()
    {
        return new Dictionary<string, object>
        {
            { "orderStatus", EnumExts.GetDescriptions<EGuiderSystemReplyType>()},
        };
    }

    /// <summary>
    /// 网格员系统工单状态日志
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("guider-work-log")]
    public async Task<PagedDto<GuiderWorkLogsOutDto>> GetGuiderWorkLogsAsync([FromQuery] GuiderWorkLogsInDto dto)
        => (await _biSnapshotApplication.GetGuiderWorkLogs(dto).ToPagedListAsync(dto)).ToPaged();

    /// <summary>
    /// 重复件-随手拍
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("duplicate")]
    public async Task<PagedDto<DuplicateItemsOutDto>> GetDuplicateItemsAsync([FromQuery] DuplicateItemsInDto dto)
    => (await _biSnapshotApplication.GetDuplicateItems(dto).ToPagedListAsync(dto)).ToPaged();

    /// <summary>
    /// 社区统计
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("community-statistics")]
    public async Task<IList<CommunityStatisticsOutDto>> GetCommunityStatisticsAsync([FromQuery] CommunityStatisticsInDto dto)
        => await _biSnapshotApplication.GetCommunityStatistics(dto).ToListAsync();

    /// <summary>
    /// 社区统计-详情
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("community-statistics-detail")]
    public async Task<PagedDto<CommunityStatisticsDetailsOutDto>> GetCommunityStatisticsDetailsAsync([FromQuery] CommunityStatisticsDetailsInDto dto)
        => (await _biSnapshotApplication.GetCommunityStatisticsDetails(dto).ToPagedListAsync(dto)).ToPaged();

    /// <summary>
    /// 随手拍区域统计
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpGet("county-redpack-statistics")]
    public async Task<IList<CountyRedPackStatisticsOutDto>> GetCountyRedPackStatisticsAsync([FromQuery] CountyRedPackStatisticsInDto dto)
        => await _biSnapshotApplication.GetCountyRedPackStatistics(dto).ToListAsync();
}
